.result, .retired, .fastest, .wildcard {
  color: #FFFFFF;
  font-variant: small-caps;
  border-radius: 15%; }

.retired {
  background-color: red; }

.fastest {
  background-color: blue; }

.wildcard {
  background-color: orange; }

.race_result.finish_1 {
  background-color: gold;
  font-size: 1.8em; }

.race_result.finish_2 {
  background-color: silver;
  font-size: 1.6em; }

.race_result.finish_3 {
  background-color: #CD7F32;
  font-size: 1.3em; }

.points {
  background-color: darkseagreen; }

tr:not(.points) {
  font-size: 0.9em; }

.result_error {
  background-color: #E34A3E; }

.champion_points, .champion_tag {
  font-size: 1.3em;
  font-weight: bolder; }

select[name='scoring'] {
  display: inline-table;
  max-width: 300px; }

span.summary_count {
  font-size: 3em; }

.driver_image.demo {
  width: 100px;
  height: 100px;
  -moz-border-radius: 50%;
  -webkit-border-radius: 50%;
  border-radius: 50%;
  border: 4px solid #5cb85c; }

.placeholder-img-text {
  position: absolute;
  left: 0;
  width: 100%;
  text-align: center;
  top: 33%;
  font-style: oblique; }

.loader-lock {
  position: absolute;
  width: 100%;
  height: 100%;
  background: yellow;
  z-index: 9999;
  opacity: 0.8; }
  .loader-lock p {
    text-align: center;
    font-size: 4em;
    position: relative;
    top: 50%; }

/*# sourceMappingURL=style.css.map */
