{% if items_plural == 'races' %}
    {% include 'driver27/admin/copy/includes/_confirm_races.html' %}
{% elif items_plural == 'teams' %}
    {% include 'driver27/admin/copy/includes/_confirm_teams.html' %}
{% elif items_plural == 'seats' %}
    {% include 'driver27/admin/copy/includes/_confirm_seats.html' %}
{% endif %}