<div class="col-xs-4 col-md-12">
    <span id="summary_race" class="summary_count" data-stat="races"
          data-original="{{ stats.RACE }}">{{ stats.RACE }}</span> races
</div>
<div class="col-xs-4 col-md-12">
    <span id="summary_pole" class="summary_count" data-stat="poles"
                                      data-original="{{ stats.POLE }}">{{ stats.POLE }}</span> poles
</div>
<div class="col-xs-4 col-md-12">
    <span id="summary_win" class="summary_count" data-stat="wins"
                                      data-original="{{ stats.WIN }}">{{ stats.WIN }}</span> wins
</div>
<div class="clearfix"></div>
<div class="col-xs-4 col-md-12">
    <span id="summary_podium" class="summary_count" data-stat="podiums"
                                      data-original="{{ stats.PODIUM }}">{{ stats.PODIUM }}</span>
    podiums
</div>
<div class="col-xs-4 col-md-12">
    <span id="summary_fastest" class="summary_count" data-stat="fastest"
                                      data-original="{{ stats.FASTEST }}">{{ stats.FASTEST }}</span>
    fastest laps
</div>
<div class="col-xs-4 col-md-12">
    <span id="summary_points" class="summary_count" data-stat="points"
                                      data-original="{{ stats.POINTS }}">{{ stats.POINTS }}</span>
    points
</div>