{% extends 'driver27/base.html' %}
{% load champion_filter i18n %}
{% block dr27_menu %}
    {% include 'driver27/global/menu-pre.html' %}
    {% include 'driver27/global/menu.html' %}
{% endblock %}
{% block dr27_content %}
    {{ block.super }}

    <table class="table table-condensed table-striped table-hover">
        <tr>
            <th class="col-md-2">{% trans 'Season' %}</th>
            <th class="col-md-2">{% trans 'Competition' %}</th>
            <th class="col-md-1">{% trans 'Year' %}</th>
            <th class="col-md-4">{% trans 'Driver leader' %}</th>
            <th class="col-md-3">{% trans 'Team leader' %}</th>
        </tr>
        <tr id="seasons-list"></tr>
    </table>
{% endblock %}

{% block bootstrap3_extra_script %}
    {{ block.super }}
    <script type="text/javascript">

        $('.loader-lock').removeClass('hide');
        var el = $('#seasons-list');
        $.get("{% url 'driver27:global:tpl' %}",
            function (data) {
                el.replaceWith(data);
                $('.loader-lock').addClass('hide');
            }
        )
        ;

    </script>
{% endblock %}