{% load i18n %}
{% if rank %}
<table class="table table-condensed table-striped table-hover">
    <tr>
        <th>{% trans 'Count' %}</th>
        <th>{% trans 'Team' %}</th>

        {% if rank_opt == 'seasons' %}
            <th>{% trans 'Season' %}</th>
        {% endif %}
    </tr>
    {% for entry in rank %}
        <tr>
            <td>{{ entry.stat }}</td>
            <td><a href="{{ entry.team.get_absolute_url }}">{{ entry.team }}</a></td>
            {% if rank_opt == 'seasons' %}
                <td>{{ entry.season }}</td>
            {% endif %}
        </tr>
    {% endfor %}

</table>
{% endif %}