{% extends 'driver27/base.html' %}
{% load i18n %}
{% block dr27_menu %}

    {% include 'driver27/_selector_menu.html' %}
    {% include 'driver27/driver/menu.html' %}
{% endblock %}
{% block dr27_content %}
    {{ block.super }}
    {% include 'driver27/driver/scoring-form.html' %}
    <div id="driver-standing" class="standing" data-standing-model="driver"></div>
{% endblock %}

{% block bootstrap3_extra_script %}
    {{ block.super }}
    {% include 'driver27/include_rank_js.html' %}
{% endblock %}