{% load i18n %}
<li class="nav-item">
    <a><<</a>
</li>
<li class="nav-item">
    <a class="nav-link" href="{% url 'driver27:global:driver' %}">{% trans 'Drivers' %}</a>
</li>

<li class="nav-item">
    <a class="nav-link" href="{% url 'driver27:global:team' %}">{% trans 'Teams' %}</a>
</li>